@@ -1,4 +1,4 @@
-// Copyright (C) 2011-2015 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2011-2023 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -8,7 +8,6 @@
 #define PKT4_H
 
 #include <asiolink/io_address.h>
-#include <dhcp/option.h>
 #include <dhcp/duid.h>
 #include <util/buffer.h>
 #include <dhcp/option.h>
@@ -20,6 +19,7 @@
 #include <iostream>
 #include <vector>
 #include <set>
+#include <list>
 
 #include <time.h>
 
@@ -55,7 +55,7 @@ public:
 
     /// Constructor, used in replying to a message.
     ///
-    /// @param msg_type type of message (e.g. DHCPDISOVER=1)
+    /// @param msg_type type of message (e.g. DHCPDISCOVER=1)
     /// @param transid transaction-id
     Pkt4(uint8_t msg_type, uint32_t transid);
 
@@ -73,7 +73,7 @@ public:
     /// Prepares on-wire format of message and all its options.
     /// Options must be stored in options_ field.
     /// Output buffer will be stored in buffer_out_.
-    /// The buffer_out_ is cleared before writting to the buffer.
+    /// The buffer_out_ is cleared before writing to the buffer.
     ///
     /// @throw InvalidOperation if packing fails
     virtual void pack();
@@ -113,7 +113,7 @@ public:
                                  const ClientIdPtr& client_id,
                                  const uint32_t transid);
 
-    /// @brief Returns text representation of the given packet identifers.
+    /// @brief Returns text representation of the given packet identifiers.
     ///
     /// This variant of the method does not include transaction id.
     ///
@@ -187,7 +187,6 @@ public:
     void
     setCiaddr(const isc::asiolink::IOAddress& ciaddr) { ciaddr_ = ciaddr; };
 
-
     /// @brief Returns siaddr field.
     ///
     /// @return siaddr field
@@ -226,6 +225,9 @@ public:
 
     /// @brief Returns DHCP message type (e.g. 1 = DHCPDISCOVER).
     ///
+    /// This method is exception safe. For packets without DHCP Message Type
+    /// option, it returns DHCP_NOTYPE (0).
+    ///
     /// @return message type
     uint8_t getType() const;
 
@@ -236,6 +238,9 @@ public:
 
     /// @brief Returns name of the DHCP message for a given type number.
     ///
+    /// This method is exception safe. For messages without DHCP Message Type
+    /// options, it returns UNKNOWN.
+    ///
     /// @param type DHCPv4 message type which name should be returned.
     ///
     /// @return Pointer to the "const" string containing DHCP message name.
@@ -263,7 +268,7 @@ public:
     ///
     /// @param sname value to be set
     /// @param sname_len length of the sname buffer (up to MAX_SNAME_LEN)
-    void setSname(const uint8_t* sname, size_t sname_len = MAX_SNAME_LEN);
+    void setSname(const uint8_t* sname, size_t sname_len);
 
     /// @brief Returns file field
     ///
@@ -279,7 +284,7 @@ public:
     /// @param file value to be set
     /// @param file_len length of the file buffer (up to MAX_FILE_LEN)
     void
-    setFile(const uint8_t* file, size_t file_len = MAX_FILE_LEN);
+    setFile(const uint8_t* file, size_t file_len);
 
     /// @brief Sets hardware address.
     ///
@@ -318,8 +323,19 @@ public:
     /// @return hardware address structure
     HWAddrPtr getHWAddr() const { return (hwaddr_); }
 
+    /// @brief Returns text representation of the hardware address
+    ///
+    /// Returns text representation of the hardware address (e.g. hwaddr=00:01:02:03:04:05).
+    /// If there is no defined hardware address, it returns @c hwaddr=(undefined).
+    ///
+    /// @return string with text representation
+    std::string getHWAddrLabel() const;
+
     /// @brief Add an option.
     ///
+    /// @note: to avoid throwing when adding multiple options
+    /// with the same type use @ref Pkt::addOption.
+    ///
     /// @throw BadValue if option with that type is already present.
     ///
     /// @param opt option to be added
@@ -357,6 +373,19 @@ public:
         return (local_hwaddr_);
     }
 
+    /// @brief Returns a reference to option codes which unpacking
+    /// will be deferred.
+    ///
+    /// Only options 43 and 224-254 are subject of deferred
+    /// unpacking: when the packet unpacking is performed, each time
+    /// such an option is found, it is unpacked as an unknown option
+    /// and the code added in this list.
+    ///
+    /// @return List of codes of options which unpacking is deferred.
+    std::list<uint16_t>& getDeferredOptions() {
+        return (deferred_options_);
+    }
+
     /// @brief Checks if a DHCPv4 message has been relayed.
     ///
     /// This function returns a boolean value which indicates whether a DHCPv4
@@ -369,7 +398,7 @@ public:
     /// (true) or non-relayed (false).
     bool isRelayed() const;
 
-    /// @brief Checks if a DHCPv4 message has beeb transported over DHCPv6
+    /// @brief Checks if a DHCPv4 message has been transported over DHCPv6
     ///
     /// @return Boolean value which indicates whether the message is
     /// transported over DHCPv6 (true) or native DHCPv4 (false)
@@ -467,13 +496,16 @@ protected:
     /// Currently it is a no-op, it always returns NULL.
     ///
     /// @return always NULL
-    virtual HWAddrPtr getMACFromRemoteIdRelayOption(){
-        return(HWAddrPtr());
+    virtual HWAddrPtr getMACFromRemoteIdRelayOption() {
+        return (HWAddrPtr());
     }
 
-    /// local HW address (dst if receiving packet, src if sending packet)
+    /// @brief local HW address (dst if receiving packet, src if sending packet)
     HWAddrPtr local_hwaddr_;
 
+    // @brief List of deferred option codes
+    std::list<uint16_t> deferred_options_;
+
     /// @brief message operation code
     ///
     /// Note: This is legacy BOOTP field. There's no need to manipulate it
@@ -523,7 +555,6 @@ protected:
 typedef boost::shared_ptr<Pkt4> Pkt4Ptr;
 
 } // isc::dhcp namespace
-
 } // isc namespace
 
 #endif
