@@ -1,4 +1,4 @@
-// File created from ../../../src/lib/dhcpsrv/dhcpsrv_messages.mes on Thu Jul 16 2020 15:23
+// File created from ../../../src/lib/dhcpsrv/dhcpsrv_messages.mes
 
 #ifndef DHCPSRV_MESSAGES_H
 #define DHCPSRV_MESSAGES_H
@@ -21,6 +21,13 @@ extern const isc::log::MessageID DHCPSRV_CFGMGR_DDNS_PARAMETER_IGNORED;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_DDNS_PARAMETER_MOVED;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_DEL_SUBNET4;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_DEL_SUBNET6;
+extern const isc::log::MessageID DHCPSRV_CFGMGR_FLQ_POPULATE_FREE_ADDRESS_LEASES;
+extern const isc::log::MessageID DHCPSRV_CFGMGR_FLQ_POPULATE_FREE_ADDRESS_LEASES_DONE;
+extern const isc::log::MessageID DHCPSRV_CFGMGR_FLQ_POPULATE_FREE_PREFIX_LEASES;
+extern const isc::log::MessageID DHCPSRV_CFGMGR_FLQ_POPULATE_FREE_PREFIX_LEASES_DONE;
+extern const isc::log::MessageID DHCPSRV_CFGMGR_IPV4_RESERVATIONS_NON_UNIQUE_IGNORED;
+extern const isc::log::MessageID DHCPSRV_CFGMGR_IPV6_RESERVATIONS_NON_UNIQUE_IGNORED;
+extern const isc::log::MessageID DHCPSRV_CFGMGR_IP_RESERVATIONS_UNIQUE_DUPLICATES_POSSIBLE;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_NEW_SUBNET4;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_NEW_SUBNET6;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_NO_SUBNET4;
@@ -29,6 +36,7 @@ extern const isc::log::MessageID DHCPSRV_CFGMGR_ONLY_SUBNET4;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_ONLY_SUBNET6;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_OPTION_DUPLICATE;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_RELAY_IP_ADDRESS_DEPRECATED;
+extern const isc::log::MessageID DHCPSRV_CFGMGR_RENEW_GTR_REBIND;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_SOCKET_RAW_UNSUPPORTED;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_SOCKET_TYPE_DEFAULT;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_SOCKET_TYPE_SELECT;
@@ -44,47 +52,12 @@ extern const isc::log::MessageID DHCPSRV_CFGMGR_UNICAST_LINK_LOCAL;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_UPDATE_SUBNET4;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_UPDATE_SUBNET6;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_USE_ADDRESS;
+extern const isc::log::MessageID DHCPSRV_CFGMGR_USE_ALLOCATOR;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_USE_UNICAST;
 extern const isc::log::MessageID DHCPSRV_CLOSE_DB;
-extern const isc::log::MessageID DHCPSRV_CQL_ADD_ADDR4;
-extern const isc::log::MessageID DHCPSRV_CQL_ADD_ADDR6;
-extern const isc::log::MessageID DHCPSRV_CQL_COMMIT;
-extern const isc::log::MessageID DHCPSRV_CQL_CONNECTION_BEGIN_TRANSACTION;
-extern const isc::log::MessageID DHCPSRV_CQL_CONNECTION_COMMIT;
-extern const isc::log::MessageID DHCPSRV_CQL_CONNECTION_ROLLBACK;
-extern const isc::log::MessageID DHCPSRV_CQL_DB;
-extern const isc::log::MessageID DHCPSRV_CQL_DEALLOC_ERROR;
-extern const isc::log::MessageID DHCPSRV_CQL_DELETE_ADDR;
-extern const isc::log::MessageID DHCPSRV_CQL_DELETE_EXPIRED_RECLAIMED4;
-extern const isc::log::MessageID DHCPSRV_CQL_DELETE_EXPIRED_RECLAIMED6;
-extern const isc::log::MessageID DHCPSRV_CQL_GET4;
-extern const isc::log::MessageID DHCPSRV_CQL_GET_ADDR4;
-extern const isc::log::MessageID DHCPSRV_CQL_GET_ADDR6;
-extern const isc::log::MessageID DHCPSRV_CQL_GET_CLIENTID;
-extern const isc::log::MessageID DHCPSRV_CQL_GET_CLIENTID_HWADDR_SUBID;
-extern const isc::log::MessageID DHCPSRV_CQL_GET_EXPIRED4;
-extern const isc::log::MessageID DHCPSRV_CQL_GET_EXPIRED6;
-extern const isc::log::MessageID DHCPSRV_CQL_GET_HOSTNAME4;
-extern const isc::log::MessageID DHCPSRV_CQL_GET_HOSTNAME6;
-extern const isc::log::MessageID DHCPSRV_CQL_GET_HWADDR;
-extern const isc::log::MessageID DHCPSRV_CQL_GET_IAID_DUID;
-extern const isc::log::MessageID DHCPSRV_CQL_GET_IAID_SUBID_DUID;
-extern const isc::log::MessageID DHCPSRV_CQL_GET_PAGE4;
-extern const isc::log::MessageID DHCPSRV_CQL_GET_PAGE6;
-extern const isc::log::MessageID DHCPSRV_CQL_GET_SUBID4;
-extern const isc::log::MessageID DHCPSRV_CQL_GET_SUBID_CLIENTID;
-extern const isc::log::MessageID DHCPSRV_CQL_GET_SUBID_HWADDR;
-extern const isc::log::MessageID DHCPSRV_CQL_GET_VERSION;
-extern const isc::log::MessageID DHCPSRV_CQL_HOST_ADD;
-extern const isc::log::MessageID DHCPSRV_CQL_HOST_DB;
-extern const isc::log::MessageID DHCPSRV_CQL_HOST_DB_GET_VERSION;
-extern const isc::log::MessageID DHCPSRV_CQL_HOST_GET4;
-extern const isc::log::MessageID DHCPSRV_CQL_HOST_GET6;
-extern const isc::log::MessageID DHCPSRV_CQL_HOST_GET_ALL;
-extern const isc::log::MessageID DHCPSRV_CQL_LEASE_EXCEPTION_THROWN;
-extern const isc::log::MessageID DHCPSRV_CQL_ROLLBACK;
-extern const isc::log::MessageID DHCPSRV_CQL_UPDATE_ADDR4;
-extern const isc::log::MessageID DHCPSRV_CQL_UPDATE_ADDR6;
+extern const isc::log::MessageID DHCPSRV_CONFIGURED_SUBNET_WITHOUT_ID;
+extern const isc::log::MessageID DHCPSRV_DDNS_TTL_PERCENT_TOO_SMALL;
+extern const isc::log::MessageID DHCPSRV_DEPRECATED;
 extern const isc::log::MessageID DHCPSRV_DHCP4O6_RECEIVED_BAD_PACKET;
 extern const isc::log::MessageID DHCPSRV_DHCP_DDNS_ERROR_EXCEPTION;
 extern const isc::log::MessageID DHCPSRV_DHCP_DDNS_HANDLER_NULL;
@@ -100,12 +73,22 @@ extern const isc::log::MessageID DHCPSRV_HOOK_LEASE6_EXTEND_SKIP;
 extern const isc::log::MessageID DHCPSRV_HOOK_LEASE6_RECOVER_SKIP;
 extern const isc::log::MessageID DHCPSRV_HOOK_LEASE6_SELECT_SKIP;
 extern const isc::log::MessageID DHCPSRV_INVALID_ACCESS;
+extern const isc::log::MessageID DHCPSRV_LEASE4_EXTENDED_INFO_SANITY_FAIL;
+extern const isc::log::MessageID DHCPSRV_LEASE4_EXTENDED_INFO_UPGRADED;
+extern const isc::log::MessageID DHCPSRV_LEASE6_EXTENDED_INFO_SANITY_FAIL;
+extern const isc::log::MessageID DHCPSRV_LEASE6_EXTENDED_INFO_UPGRADED;
+extern const isc::log::MessageID DHCPSRV_LEASE_MGR_CALLBACK_EXCEPTION;
+extern const isc::log::MessageID DHCPSRV_LEASE_MGR_CALLBACK_UNKNOWN_EXCEPTION;
 extern const isc::log::MessageID DHCPSRV_LEASE_SANITY_FAIL;
 extern const isc::log::MessageID DHCPSRV_LEASE_SANITY_FAIL_DISCARD;
 extern const isc::log::MessageID DHCPSRV_LEASE_SANITY_FIXED;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_ADD_ADDR4;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_ADD_ADDR6;
+extern const isc::log::MessageID DHCPSRV_MEMFILE_BEGIN_BUILD_EXTENDED_INFO_TABLES6;
+extern const isc::log::MessageID DHCPSRV_MEMFILE_BEGIN_EXTRACT_EXTENDED_INFO4;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_BEGIN_TRANSACTION;
+extern const isc::log::MessageID DHCPSRV_MEMFILE_BUILD_EXTENDED_INFO_TABLES6;
+extern const isc::log::MessageID DHCPSRV_MEMFILE_BUILD_EXTENDED_INFO_TABLES6_ERROR;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_COMMIT;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_CONVERTING_LEASE_FILES;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_DB;
@@ -113,13 +96,14 @@ extern const isc::log::MessageID DHCPSRV_MEMFILE_DELETE_ADDR;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_DELETE_EXPIRED_RECLAIMED4;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_DELETE_EXPIRED_RECLAIMED6;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_DELETE_EXPIRED_RECLAIMED_START;
+extern const isc::log::MessageID DHCPSRV_MEMFILE_EXTRACT_EXTENDED_INFO4;
+extern const isc::log::MessageID DHCPSRV_MEMFILE_EXTRACT_EXTENDED_INFO4_ERROR;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET4;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET6;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET6_DUID;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_ADDR4;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_ADDR6;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_CLIENTID;
-extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_CLIENTID_HWADDR_SUBID;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_EXPIRED4;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_EXPIRED6;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_HOSTNAME4;
@@ -127,8 +111,13 @@ extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_HOSTNAME6;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_HWADDR;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_IAID_DUID;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_IAID_SUBID_DUID;
+extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_LINKADDR6;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_PAGE4;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_PAGE6;
+extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_RELAYID4;
+extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_RELAYID6;
+extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_REMOTEID4;
+extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_REMOTEID6;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_SUBID4;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_SUBID6;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_SUBID_CLIENTID;
@@ -155,6 +144,7 @@ extern const isc::log::MessageID DHCPSRV_MEMFILE_WIPE_LEASES4;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_WIPE_LEASES4_FINISHED;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_WIPE_LEASES6;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_WIPE_LEASES6_FINISHED;
+extern const isc::log::MessageID DHCPSRV_MT_DISABLED_QUEUE_CONTROL;
 extern const isc::log::MessageID DHCPSRV_MULTIPLE_RAW_SOCKETS_PER_IFACE;
 extern const isc::log::MessageID DHCPSRV_MYSQL_ADD_ADDR4;
 extern const isc::log::MessageID DHCPSRV_MYSQL_ADD_ADDR6;
@@ -179,8 +169,11 @@ extern const isc::log::MessageID DHCPSRV_MYSQL_GET_HOSTNAME6;
 extern const isc::log::MessageID DHCPSRV_MYSQL_GET_HWADDR;
 extern const isc::log::MessageID DHCPSRV_MYSQL_GET_IAID_DUID;
 extern const isc::log::MessageID DHCPSRV_MYSQL_GET_IAID_SUBID_DUID;
+extern const isc::log::MessageID DHCPSRV_MYSQL_GET_LINKADDR6;
 extern const isc::log::MessageID DHCPSRV_MYSQL_GET_PAGE4;
 extern const isc::log::MessageID DHCPSRV_MYSQL_GET_PAGE6;
+extern const isc::log::MessageID DHCPSRV_MYSQL_GET_RELAYID4;
+extern const isc::log::MessageID DHCPSRV_MYSQL_GET_REMOTEID4;
 extern const isc::log::MessageID DHCPSRV_MYSQL_GET_SUBID4;
 extern const isc::log::MessageID DHCPSRV_MYSQL_GET_SUBID6;
 extern const isc::log::MessageID DHCPSRV_MYSQL_GET_SUBID_CLIENTID;
@@ -189,11 +182,25 @@ extern const isc::log::MessageID DHCPSRV_MYSQL_GET_VERSION;
 extern const isc::log::MessageID DHCPSRV_MYSQL_HOST_DB;
 extern const isc::log::MessageID DHCPSRV_MYSQL_HOST_DB_GET_VERSION;
 extern const isc::log::MessageID DHCPSRV_MYSQL_HOST_DB_READONLY;
+extern const isc::log::MessageID DHCPSRV_MYSQL_HOST_DB_RECONNECT_ATTEMPT_FAILED;
+extern const isc::log::MessageID DHCPSRV_MYSQL_HOST_DB_RECONNECT_ATTEMPT_SCHEDULE;
+extern const isc::log::MessageID DHCPSRV_MYSQL_HOST_DB_RECONNECT_FAILED;
+extern const isc::log::MessageID DHCPSRV_MYSQL_LEASE_DB_RECONNECT_ATTEMPT_FAILED;
+extern const isc::log::MessageID DHCPSRV_MYSQL_LEASE_DB_RECONNECT_ATTEMPT_SCHEDULE;
+extern const isc::log::MessageID DHCPSRV_MYSQL_LEASE_DB_RECONNECT_FAILED;
 extern const isc::log::MessageID DHCPSRV_MYSQL_NEGATIVE_LEASES_STAT;
+extern const isc::log::MessageID DHCPSRV_MYSQL_NO_TLS;
 extern const isc::log::MessageID DHCPSRV_MYSQL_ROLLBACK;
 extern const isc::log::MessageID DHCPSRV_MYSQL_START_TRANSACTION;
+extern const isc::log::MessageID DHCPSRV_MYSQL_TLS_CIPHER;
 extern const isc::log::MessageID DHCPSRV_MYSQL_UPDATE_ADDR4;
 extern const isc::log::MessageID DHCPSRV_MYSQL_UPDATE_ADDR6;
+extern const isc::log::MessageID DHCPSRV_MYSQL_UPGRADE_BINARY_ADDRESS6;
+extern const isc::log::MessageID DHCPSRV_MYSQL_UPGRADE_BINARY_ADDRESS6_ERROR;
+extern const isc::log::MessageID DHCPSRV_MYSQL_UPGRADE_BINARY_ADDRESS6_PAGE;
+extern const isc::log::MessageID DHCPSRV_MYSQL_UPGRADE_EXTENDED_INFO4;
+extern const isc::log::MessageID DHCPSRV_MYSQL_UPGRADE_EXTENDED_INFO4_ERROR;
+extern const isc::log::MessageID DHCPSRV_MYSQL_UPGRADE_EXTENDED_INFO4_PAGE;
 extern const isc::log::MessageID DHCPSRV_NOTYPE_DB;
 extern const isc::log::MessageID DHCPSRV_NO_SOCKETS_OPEN;
 extern const isc::log::MessageID DHCPSRV_OPEN_SOCKET_FAIL;
@@ -220,8 +227,11 @@ extern const isc::log::MessageID DHCPSRV_PGSQL_GET_HOSTNAME6;
 extern const isc::log::MessageID DHCPSRV_PGSQL_GET_HWADDR;
 extern const isc::log::MessageID DHCPSRV_PGSQL_GET_IAID_DUID;
 extern const isc::log::MessageID DHCPSRV_PGSQL_GET_IAID_SUBID_DUID;
+extern const isc::log::MessageID DHCPSRV_PGSQL_GET_LINKADDR6;
 extern const isc::log::MessageID DHCPSRV_PGSQL_GET_PAGE4;
 extern const isc::log::MessageID DHCPSRV_PGSQL_GET_PAGE6;
+extern const isc::log::MessageID DHCPSRV_PGSQL_GET_RELAYID4;
+extern const isc::log::MessageID DHCPSRV_PGSQL_GET_REMOTEID4;
 extern const isc::log::MessageID DHCPSRV_PGSQL_GET_SUBID4;
 extern const isc::log::MessageID DHCPSRV_PGSQL_GET_SUBID6;
 extern const isc::log::MessageID DHCPSRV_PGSQL_GET_SUBID_CLIENTID;
@@ -230,14 +240,38 @@ extern const isc::log::MessageID DHCPSRV_PGSQL_GET_VERSION;
 extern const isc::log::MessageID DHCPSRV_PGSQL_HOST_DB;
 extern const isc::log::MessageID DHCPSRV_PGSQL_HOST_DB_GET_VERSION;
 extern const isc::log::MessageID DHCPSRV_PGSQL_HOST_DB_READONLY;
+extern const isc::log::MessageID DHCPSRV_PGSQL_HOST_DB_RECONNECT_ATTEMPT_FAILED;
+extern const isc::log::MessageID DHCPSRV_PGSQL_HOST_DB_RECONNECT_ATTEMPT_SCHEDULE;
+extern const isc::log::MessageID DHCPSRV_PGSQL_HOST_DB_RECONNECT_FAILED;
+extern const isc::log::MessageID DHCPSRV_PGSQL_LEASE_DB_RECONNECT_ATTEMPT_FAILED;
+extern const isc::log::MessageID DHCPSRV_PGSQL_LEASE_DB_RECONNECT_ATTEMPT_SCHEDULE;
+extern const isc::log::MessageID DHCPSRV_PGSQL_LEASE_DB_RECONNECT_FAILED;
 extern const isc::log::MessageID DHCPSRV_PGSQL_NEGATIVE_LEASES_STAT;
+extern const isc::log::MessageID DHCPSRV_PGSQL_NO_TLS_SUPPORT;
 extern const isc::log::MessageID DHCPSRV_PGSQL_ROLLBACK;
 extern const isc::log::MessageID DHCPSRV_PGSQL_START_TRANSACTION;
+extern const isc::log::MessageID DHCPSRV_PGSQL_TLS_SUPPORT;
 extern const isc::log::MessageID DHCPSRV_PGSQL_UPDATE_ADDR4;
 extern const isc::log::MessageID DHCPSRV_PGSQL_UPDATE_ADDR6;
+extern const isc::log::MessageID DHCPSRV_PGSQL_UPGRADE_BINARY_ADDRESS6;
+extern const isc::log::MessageID DHCPSRV_PGSQL_UPGRADE_BINARY_ADDRESS6_ERROR;
+extern const isc::log::MessageID DHCPSRV_PGSQL_UPGRADE_BINARY_ADDRESS6_PAGE;
+extern const isc::log::MessageID DHCPSRV_PGSQL_UPGRADE_EXTENDED_INFO4;
+extern const isc::log::MessageID DHCPSRV_PGSQL_UPGRADE_EXTENDED_INFO4_ERROR;
+extern const isc::log::MessageID DHCPSRV_PGSQL_UPGRADE_EXTENDED_INFO4_PAGE;
 extern const isc::log::MessageID DHCPSRV_QUEUE_NCR;
 extern const isc::log::MessageID DHCPSRV_QUEUE_NCR_FAILED;
 extern const isc::log::MessageID DHCPSRV_QUEUE_NCR_SKIP;
+extern const isc::log::MessageID DHCPSRV_SUBNET4O6_SELECT_FAILED;
+extern const isc::log::MessageID DHCPSRV_SUBNET4_SELECT_BY_ADDRESS_NO_MATCH;
+extern const isc::log::MessageID DHCPSRV_SUBNET4_SELECT_BY_INTERFACE_NO_MATCH;
+extern const isc::log::MessageID DHCPSRV_SUBNET4_SELECT_BY_RELAY_ADDRESS_NO_MATCH;
+extern const isc::log::MessageID DHCPSRV_SUBNET4_SELECT_NO_RAI_OPTIONS;
+extern const isc::log::MessageID DHCPSRV_SUBNET4_SELECT_NO_RELAY_ADDRESS;
+extern const isc::log::MessageID DHCPSRV_SUBNET4_SELECT_NO_USABLE_ADDRESS;
+extern const isc::log::MessageID DHCPSRV_SUBNET6_SELECT_BY_ADDRESS_NO_MATCH;
+extern const isc::log::MessageID DHCPSRV_SUBNET6_SELECT_BY_INTERFACE_ID_NO_MATCH;
+extern const isc::log::MessageID DHCPSRV_SUBNET6_SELECT_BY_INTERFACE_NO_MATCH;
 extern const isc::log::MessageID DHCPSRV_TIMERMGR_CALLBACK_FAILED;
 extern const isc::log::MessageID DHCPSRV_TIMERMGR_REGISTER_TIMER;
 extern const isc::log::MessageID DHCPSRV_TIMERMGR_RUN_TIMER_OPERATION;
